# README - SpriteResourceManager

Version 5

## Overview

This is a compiled version of the SpriteResourceManager that has
functionality to manage Sprites as part of the Resource Manager from
the [Dragonfly Book](https://dragonfly.wpi.edu/), version 7.

To be used, the SpriteResourceManager *must* be accompanied by
implementations for Dragonfly Naiad (i.e., up to Development
Checkpoint #7).  In addition, the following classes are needed:

+ Color: `Color.h`
+ Frame: `Frame.h` and `Frame.cpp`
+ Sprite: `Sprite.h` and `Sprite.cpp`

See Section 4.12 of the book for details.

Then, upon reaching Development Checkpoint #8, step #5:

+ ResourceManager: `ResourceManager.h`

should be derived from SpriteResourceManager:

```c++
// ResourceManager.h

class ResourceManager : public SpriteResourceManager {
   ...
};
```

## Files

Platforms, organized by directory:

- `windows/`
- `linux/`
- `mac/`

Relevant files under each directory:

- `SpriteResourceManager.o` or `SpriteResourceManager.obj` - the compiled manager
- `SpriteResourceManager.h` - the header file

In addition, there is a directory for testing (see below):

- `test/` - contains test code to run and a `sprites/` directory with
  sprites.

## Install

Linux/Mac: Copy the `.o` and `.h` files appropriate to your platform
to your project directory as well as the `sprites/` directory and its
contents.

Windows: Copy the `.obj` and `.h` files to your project directory
where you have all your other source files.  Right click on your
project in the Solution Explorer window, select "Add" -> "Existing
Item" and choose both `SpriteResourceManager.obj` and
`SpriteResourceManager.h`.  **Important!** For developing with
"Debug", do *not* use the "release" version - that is only when
building for "Release" (e.g., when you ship your game).

## Testing

After building all necessary classes, test by using the test sprites
and the code included in `test/`.  After compiling and running, you
should find a file named `dragonfly.log` file with:

````
LM::startUp(): Successfully started.
SRM::startUp(): Successfully started.
RM::startUp(): Successfully started.
SRM::loadSprite(): Loading sprite 'sprites/good-spr.txt'.
SRM::loadSprite(): Opened file 'sprites/good-spr.txt'.
	      Frames: 5
	       Width: 6
	      Height: 2
	    Slowdown: 4
	       Color: green
SRM::loadSprite(): Sprite 'good' loaded.
testGood: PASS
SRM::loadSprite(): Loading sprite 'sprites/bad-spr.txt'.
SRM::loadSprite(): Opened file 'sprites/bad-spr.txt'.
SRM::loadSprite(): Warning! No 'color' in header.
SRM::loadSprite(): Warning! No 'slowdown' in header.
	      Frames: 2
	       Width: 4
	      Height: 2
	    Slowdown: 0
	       Color: default
	Error! Line 10: No more frame data before 'end'.
SRM::loadSprite(): Error! No frame data to add.
SRM::loadSprite(): Sprite 'bad' not loaded.
testBad: PASS
SRM::loadSprite(): Loading sprite 'sprites/map-spr.txt'.
SRM::loadSprite(): Opened file 'sprites/map-spr.txt'.
	      Frames: 1
	       Width: 100
	      Height: 35
	    Slowdown: 0
	       Color: white
	Error! Line 44: No more frame data before 'end'.
SRM::loadSprite(): Error! No frame data to add.
SRM::loadSprite(): Sprite 'map' not loaded.
testBigBad: PASS
----------------------
Summary: 3 of 3 tests pass.
SUCCESS
----------------------
SRM::shutDown(): Successfully stopped.
RM::shutDown(): Successfully stopped.
LM::shutDown(): Successfully stopped.
````

If you do *not* see **"SUCCESS"** at the end, there was some problem.
Please contact the teaching staff.

## Troubleshooting

If you have linker errors when compiling, make sure your
signatures are *exactly* the same as specified in the book.

## Next

Use in implementing your fully functional, full-featured game engine.

Happy resource-managing!

-- Mark, `claypool@cs.wpi.edu`
